# 分析game_xxx_server帮我按照如下规则生成对应代码到game_xxx_client
    1. 分析game_xxx_server中./src/rpc目录下的*.event.ts文件生成对应rpc到game_xxx_client的api.ts中
    2. 分析game_xxx_server中./src/struct目录下的.rs文件生成前端订阅代码到base.ts中的__init方法中

具体内容如下:

## 生成rpc方法到game_xxx_client的api.ts中

### 前端RPC范例如下:

```ts
// 导入模块
import { clientRpc } from "pi_network/client_net/net_env";
import { recruitArg } from '后端模块名 + /struct/ + 功能名 + .struct';
import { example1, example2, example3 } from '后端模块名 + /rpc/ + 文件名 + .event';

//RPC接口示例1
export const example1 = async () => {
    return await executeRpc(example1._$topic);
}

//RPC接口示例2
export const example2 = async (mapId: number) => {
    return await executeRpc(example2._$topic, mapId);
}

//RPC接口示例3
export const example3 = async (actID: number, mapID: number, aim: number, idx: number, team: number[][]) => {
    const param = new recruitArg();
    Object.assign(param, { actID, mapID, aim, idx, team });
    return await executeRpc(example3._$topic, param);
}
```

### 导入模块说明

- xxx为导入模块中的'功能名'
- *.event.ts中的*表示'文件名'
- _$topic字段是后端rpc方法的属性
- game_xxx_server为导入模块中的'后端模块名'
- 按需从项目中对应的event.ts中导入对应的rpc方法

### 前端rpc参数说明

- 生成的每个rpc函数可能有不同的参数结构
- rid和uid不作为前端接口参数而是由后端处理
- 根据后端接口的第三个参数的类型生成对应的前端函数参数
    + 后端接口中第三个参数不存在(参考example1)
        * 前端rpc无参
    + 后端接口中第三个参数不是struct实例对象(参考example2)
        * 前端rpc参数为后端接口参数
    + 后端接口中第三个参数是struct实例对象(参考example3)
        * 前端rpc为多参函数,各参数名称对应为struct实例解构对象的属性名
        * 参数类型参考game_xxx_server/src/struct目录下的.rs文件对应的struct属性类型
        * 通过Object.assign方式为struct实例对象赋值

## 生成前端订阅代码到base.ts中的__init方法中

### 前端订阅代码范例如下:

```ts
// 导入模块
import { Network } from "pi_network/client_net/network";
import { UserCycleCardDB, UserCycleCardDB1 } from '后端模块名 + /struct/ + 功能名 + .struct';

//订阅单张表范例
Network.sub({ subStruct: UserCycleCardDB });

//订阅多张表范例
Network.subMore([{
    subStruct: UserCycleCardDB
},{
    subStruct: UserCycleCardDB1
}])
```

### 订阅代码说明

- 只需订阅后端结构中有dbMonitor=true注释字段的结构
- 项目中.rs文件中有满足条件的结构都需要导入对应的.struct文件

# 只需要帮我按要求生成对应代码,不需要解决生成代码中模块找不到问题